Module prelude

Module prelude 

The prelude: a collection of commonly-used types, traits, and functions.

Importing the prelude brings the most ergonomically important items into scope:

use or_panic::prelude::*;

This is purely for convenience—everything in the prelude is also available through their regular module paths.

Re-exports

pub use crate::OptionOrPanic;
pub use crate::ResultOrPanic;